@@ -91,7 +91,7 @@ class CGContentUtils extends CGExtensions
    ---------------------------------------------------------*/
   function GetVersion()
   {
-    return '1.2';
+    return '1.3';
   }
 
 
@@ -127,7 +127,7 @@ class CGContentUtils extends CGExtensions
    ---------------------------------------------------------*/
   function GetChangeLog()
   {
-    return $this->Lang('changelog');
+    return file_get_contents(dirname(__FILE__).'/changeloc.inc');
   }
   
   /*---------------------------------------------------------
@@ -204,7 +204,7 @@ class CGContentUtils extends CGExtensions
   function GetHeaderHTML()
   {
     $txt = '';
-    $obj =& $this->GetModuleInstance('JQueryTools');
+    $obj = $this->GetModuleInstance('JQueryTools');
     if( is_object($obj) )
       {
 $tmpl = <<<EOT
@@ -222,7 +222,7 @@ EOT;
    ---------------------------------------------------------*/
   function MinimumCMSVersion()
   {
-    return "1.8.2";
+    return "1.9.4.3";
   }
 	
 	
@@ -286,16 +286,34 @@ EOT;
    ---------------------------------------------------------*/
   function _exportContent($start_id,$children)
   {
-    global $gCms;
-    $hm =& $gCms->GetHierarchyManager();
+    $gCms = cmsms();
+    $hm = $gCms->GetHierarchyManager();
 
     $this->_dom = new DOMDocument("1.0","UTF8");
     $root = $this->_dom->createElement('cms_export');
 
-    $node =& $hm->sureGetNodeByID($start_id);
-    $parent_domnode = $this->_exportContentObj($node,$children);
-
-    $root->appendChild($parent_domnode);
+    if( $start_id == -1 )
+      {
+	$children = TRUE;
+	$allchildren = $hm->getChildren(TRUE);
+	foreach( $allchildren as $child )
+	  {
+	    $domnode = $this->_exportContentObj($child,$children);
+	    if( $domnode )
+	      {
+		$root->appendChild($domnode);
+	      }
+	  }
+      }
+    else
+      {
+	$node = $hm->sureGetNodeByID($start_id);
+	$parent_domnode = $this->_exportContentObj($node,$children);
+	if( $parent_domnode )
+	  {
+	    $root->appendChild($parent_domnode);
+	  }
+      }
     $this->_dom->appendChild($root);
     return $this->_dom->saveXML();
   }
@@ -306,7 +324,8 @@ EOT;
    ---------------------------------------------------------*/
   function _exportContentObj(&$node,$children)
   {
-    $content_obj =& $node->getContent();    
+    $content_obj = $node->getContent(false,true,false);
+    if( !is_object($content_obj) ) return;
     $domnode = $this->_createDomContentObj($content_obj);
 
     if( $node->hasChildren() && $children )
@@ -330,8 +349,8 @@ EOT;
   {
     if( !$this->_default_template )
       {
-	global $gCms;
-	$templateops =& $gCms->GetTemplateOperations();
+	$gCms = cmsms();
+	$templateops = $gCms->GetTemplateOperations();
 	$this->_default_template = $templateops->LoadDefaultTemplate();
       }
     return $this->_default_template->id;
@@ -345,8 +364,8 @@ EOT;
   {
     if( !$this->_template_cache )
       {
-	global $gCms;
-	$db =& $gCms->GetDb();
+	$gCms = cmsms();
+	$db = $gCms->GetDb();
 	$query = 'SELECT template_id,template_name FROM '.cms_db_prefix().'templates ';
 	$tmp = $db->GetArray($query);
 	$this->_template_cache = cge_array::to_hash($tmp,'template_id');
@@ -494,7 +513,7 @@ EOT;
       {
 	if( $node->nodeName != 'cms_content' ) break;
       
-	$content_obj =& $this->_extractDomContentObj($node);
+	$content_obj = $this->_extractDomContentObj($node);
 	if( $content_obj )
 	  {
 	    echo "DEBGUG: FOUND ".$content_obj->Name().' with parent '.$parent_id.'<br/>';
@@ -517,7 +536,7 @@ EOT;
       {
 	if( $node->nodeName == 'cms_content' )
 	  {
-	    $content_obj =& $this->_extractDomContentObj($node);
+	    $content_obj = $this->_extractDomContentObj($node);
 	    if( $content_obj )
 	      {
 		//save it
@@ -543,14 +562,14 @@ EOT;
   function &_extractDomContentObj(&$node)
     {
       /////////////////////////////////////////////////////////////////
-      global $gCms;
-      $contentops =& $gCms->getContentOperations();
+      $gCms = cmsms();
+      $contentops = $gCms->getContentOperations();
 
       // a. get the content type
       $contenttype = $this->_get_childnode_value($node,'type');
 
       // b. create the new content object for filling.
-      $content_obj =& $contentops->CreateNewContent($contenttype);
+      $content_obj = $contentops->CreateNewContent($contenttype);
       if( !$content_obj ) return NULL;
 
       $content_obj->SetName($this->_get_node_attribute($node,'name'));
@@ -617,6 +636,68 @@ EOT;
     if( empty($blockName) ) return FALSE;
     if( !isset($params['name']) ) return FALSE;
     $name = trim($params['name']);
+
+    if( isset($params['groups']) && !$this->CheckPermission('Manage All Content')) // manage all content is just that... manage everything.
+      {
+	// groups are specified, and we don't get superuser privilege.
+	$my_uid = get_userid(FALSE); 
+	if( $my_uid <= 0 ) return FALSE; // not loggedin?
+
+	$allgroups = array();
+	{
+	  // get a hash of all of the groups and ids.
+	  $tmp = cmsms()->GetGroupOperations()->LoadGroups();
+	  if( !is_array($tmp) || count($tmp) == 0 ) return FALSE; // no groups?
+	  foreach( $tmp as $one )
+	    {
+	      if( !$one->active ) continue;
+	      $allgroups[$one->name] = $one->id;
+	    }
+	}
+
+	// get the gids of all of the groups that this field is visible to.
+	$groups = array();
+	$tmp = explode(',',$params['groups']);
+	foreach( $tmp as $one )
+	  {
+	    $one = trim($one);
+	    if( $one )
+	      {
+		if( !isset($allgroups[$one]) ) continue;
+		$groups[] = $allgroups[$one];
+	      }
+	  }
+
+	if( count($groups) == 0 ) 
+	  {
+	    // no valid groups specified... user has to be an administrator
+	    $groups[] = 1;
+	  }
+
+	// now do the check to see if the current user is a member of the specified group(s)
+	$groups = array_unique($groups);
+	$valid = FALSE;
+	foreach( $groups as $gid )
+	  {
+	    $users = cmsms()->GetUserOperations()->LoadUsersInGroup($gid);
+	    if( !is_array($users) || !count($users) ) continue;
+	    foreach( $users as $user )
+	      {
+		if( $user->id == $my_uid )
+		  {
+		    $valid = TRUE;
+		    break;
+		  }
+	      }
+	    if( $valid ) break;
+	  }
+	if( !$valid )
+	  {
+	    // user is not a member of any of the specified groups
+	    return FALSE;
+	  }
+      }
+
     $query = 'SELECT * FROM '.cms_db_prefix().'module_cgcontentutils WHERE name = ?';
     $row = $db->GetRow($query,array($name));
     if( !$row ) return FALSE;
@@ -670,8 +751,8 @@ EOT;
 
       case 'checkbox':
 	{
-	  if( $value == '' ) $value = $row['value'];
-	  $txt = $this->CreateInputCheckbox('',$blockName,$row['attribs']['value'],$value);
+	  if( $value == '' && isset($row['options']['value']) ) $value = $row['options']['value'];
+	  $txt = $this->CreateInputHidden('',$blockName,isset($row['value'])?$row['value']:'').$this->CreateInputCheckbox('',$blockName,$row['attribs']['value'],$value);
 	}
 	break;
 
@@ -738,7 +819,7 @@ EOT;
 	    }
 
 	  $opts = array();
-	  $url_prefix = $config['uploads_url'].$row['attribs']['dir'].'/';
+	  $url_prefix = $config['uploads_url'].'/'.$row['attribs']['dir'];
 	  for( $i = 0; $i < count($fl); $i++ )
 	    {
 	      $opts[$fl[$i]] = $url_prefix.$fl[$i];
@@ -762,8 +843,8 @@ EOT;
 
   function ValidateContentBlockValue($blockName,$value,$blockparams)
   {
-    global $gCms;
-    $db =& $gCms->GetDb();
+    $gCms = cmsms();
+    $db = $gCms->GetDb();
 
     if( empty($blockName) ) return FALSE;
     if( !isset($params['name']) ) return FALSE;
